

from __future__ import annotations

from typing_extensions import Required, Annotated, TypedDict

from ..._utils import PropertyInfo

__all__ = ["HighlvlvpcRetrieveInstanceParams"]


class HighlvlvpcRetrieveInstanceParams(TypedDict, total=False):
    krn: Required[str]
    """The KRN of the instance to retrieve."""

    k_customer_id: Required[Annotated[str, PropertyInfo(alias="k-customer-id")]]

    x_account_id: Required[Annotated[str, PropertyInfo(alias="x-account-id")]]



from krutrim_client import KrutrimClient
import os
from dotenv import load_dotenv

load_dotenv()

api_key = os.getenv("api_key")

client = KrutrimClient(api_key = api_key)


try:
    create_sshkey_response = client.sshkey.create_sshkey(
        key_name = "Enter the Key Name",
        public_key = "Enter the Public key",
        x_region = "Enter the region",
        # x_region possible values "In-Bangalore-1","In-Hyderabad-1"
    )
    print(f"Successfully Created the SSHKEY {create_sshkey_response}")
except Exception as e:
    print(f"Exception occured {e}")


from krutrim_client import KrutrimClient
import os
from dotenv import load_dotenv

load_dotenv()

api_key = os.getenv("api_key")

client = KrutrimClient(api_key = api_key)

try:
    search_ports_resp = client.highlvlvpc.search_ports(
        x_region = "Enter the region",
        # x_region possible values "In-Bangalore-1","In-Hyderabad-1"
    )
    print(f"successfully fetched the ports:  {search_ports_resp}")
except Exception as e:
    print(f"Exception has occured:  {e}")




from __future__ import annotations

from typing_extensions import Required, Annotated, TypedDict

from ..._utils import PropertyInfo

__all__ = ["HighlvlvpcGetVpcTaskStatusParams"]


class HighlvlvpcGetVpcTaskStatusParams(TypedDict, total=False):
    task_id: Required[str]
    """The task ID of the VPC operation"""

    k_customer_id: Required[Annotated[str, PropertyInfo(alias="k-customer-id")]]

    x_account_id: Required[Annotated[str, PropertyInfo(alias="x-account-id")]]
